pm4py.algo.conformance.multialignments package
==============================================

Subpackages
-----------

.. toctree::
   :maxdepth: 4

   pm4py.algo.conformance.multialignments.variants

Submodules
----------

pm4py.algo.conformance.multialignments.algorithm module
-------------------------------------------------------

.. automodule:: pm4py.algo.conformance.multialignments.algorithm
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: pm4py.algo.conformance.multialignments
   :members:
   :undoc-members:
   :show-inheritance:
